summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/GF/Infra/ReadFiles.hs8
-rw-r--r--src/Makefile2
2 files changed, 7 insertions, 3 deletions
diff --git a/src/Makefile b/src/Makefile
index 8c38af09f..8bb19413c 100644
--- a/src/Makefile
+++ b/src/Makefile
@@ -62,7 +62,7 @@ endif
.PHONY: all unix jar tags gfdoc windows install install-gf \
lib temp install-gfdoc install-editor \
- today help clean windows-msi
+ today help clean windows-msi dist
all: unix gfdoc $(BUILD_JAR)
diff --git a/src/GF/Infra/ReadFiles.hs b/src/GF/Infra/ReadFiles.hs
index e1e2e06d8..699eb5081 100644
--- a/src/GF/Infra/ReadFiles.hs
+++ b/src/GF/Infra/ReadFiles.hs
@@ -220,8 +220,12 @@ getImports ps = get [] where
tryRead name = do
file <- do
let file_gf = gfFile name
- b <- doesFileExistPath ps file_gf -- try gf file first
- if b then return file_gf else return (gfcFile name) -- gfc next
+ b <- doesFileExistPath ps file_gf -- try gf file first
+ if b then return file_gf else do
+ let file_gfr = gfrFile name
+ bb <- doesFileExistPath ps file_gfr -- gfr file next
+ if bb then return file_gfr else do
+ return (gfcFile name) -- gfc next
readFileIfPath ps $ file